OC.L10N.register(
    "core",
    {
    "Please select a file." : "Valitse tiedosto.",
    "File is too big" : "Tiedosto on liian suuri",
    "The selected file is not an image." : "Valittu tiedosto ei ole kuva.",
    "The selected file cannot be read." : "Valittua tiedostoa ei voi lukea.",
    "Invalid file provided" : "Määritetty virheellinen tiedosto",
    "No image or file provided" : "Kuvaa tai tiedostoa ei määritelty",
    "Unknown filetype" : "Tuntematon tiedostotyyppi",
    "Invalid image" : "Virheellinen kuva",
    "An error occurred. Please contact your admin." : "Tapahtui virhe. Ota yhteys ylläpitoon.",
    "No temporary profile picture available, try again" : "Väliaikaista profiilikuvaa ei ole käytettävissä, yritä uudelleen",
    "No crop data provided" : "Leikkaustietoa ei annettu",
    "No valid crop data provided" : "Kelvollisia leikkaustietoja ei määritetty",
    "Crop is not square" : "Leikkaus ei ole neliö",
    "Could not complete login" : "Kirjautumista ei voitu suorittaa loppuun",
    "Password reset is disabled" : "Salasanan palautus poistettu käytöstä",
    "Couldn't reset password because the token is invalid" : "Salasanaa ei voitu palauttaa, koska valtuutus on virheellinen",
    "Couldn't reset password because the token is expired" : "Salasanaa ei voitu palauttaa, koska valtuutus on vanhentunut",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Salasanan palautusviestiä ei voitu lähettää sähköpostitse, koska käyttäjätunnukselle ei ole määritetty sähköpostiosoitetta. Ota yhteys ylläpitäjään.",
    "%s password reset" : "%s salasanan palautus",
    "Password reset" : "Salasanan palautus",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Paina oheista painiketta palauttaaksesi salasanasi. Jos et ole pyytänyt salasanan palautusta, jätä tämä sähköpostiviesti huomioimatta.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Paina oheista linkkiä palauttaaksesi salasanasi. Jos et ole pyytänyt salasanan palautusta, jätä tämä sähköpostiviesti huomioimatta.",
    "Reset your password" : "Palauta salasanasi",
    "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
    "Couldn't send reset email. Please make sure your username is correct." : "Palautussähköpostin lähettäminen ei onnistunut. Varmista, että käyttäjätunnuksesi on oikein.",
    "Some of your link shares have been removed" : "Jotkin linkkijakosi on poistettu",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Tietoturvaongelman vuoksi jouduimme poistaa joitakin linkkijakojasi. Lue lisätietoja linkin kautta.",
    "Preparing update" : "Valmistellaan päivitystä",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Korjausvaihe:",
    "Repair info:" : "Korjaustiedot:",
    "Repair warning:" : "Korjausvaroitus:",
    "Repair error:" : "Korjausvirhe:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Käytä komentorivipäivitintä, koska automaattinen päivitys on estetty config.php-asetustiedostossa.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Tarkistetaan taulua %s",
    "Turned on maintenance mode" : "Siirrytty huoltotilaan",
    "Turned off maintenance mode" : "Poistuttu huoltotilasta",
    "Maintenance mode is kept active" : "Huoltotila pidetään aktiivisena",
    "Updating database schema" : "Päivitetään tietokannan skeemaa",
    "Updated database" : "Tietokanta päivitetty",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Tarkistetaan, onko tietokannan skeemaa mahdollista päivittää (tämä saattaa kestää kauan riippuen tietokannan koosta)",
    "Checked database schema update" : "Tarkistettu tietokannan skeemapäivitys",
    "Checking updates of apps" : "Tarkistetaan sovellusten päivityksiä",
    "Checking for update of app \"%s\" in appstore" : "Päivitystä sovellukseen \"%s\" tarkistetaan sovelluskaupasta",
    "Update app \"%s\" from appstore" : "Päivitä sovellus \"%s\" sovelluskaupasta",
    "Checked for update of app \"%s\" in appstore" : "Päivitys sovellukseen \"%s\" tarkistettu sovelluskaupasta",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tarkistetaan, onko kohteen %s tietokannan skeemaa mahdollista päivittää (tämä saattaa kestää kauan riippuen tietokannan koosta)",
    "Checked database schema update for apps" : "Tarkistettu tietokannan skeemapäivitys sovelluksille",
    "Updated \"%1$s\" to %2$s" : "Päivitetty \"%1$s\" versioon %2$s",
    "Set log level to debug" : "Asetettu lokitasoksi vianetsintä",
    "Reset log level" : "Nollattu lokitaso",
    "Starting code integrity check" : "Aloitetaan koodin eheystarkistus",
    "Finished code integrity check" : "Koodin eheystarkistus suoritettu",
    "%s (incompatible)" : "%s (ei yhteensopiva)",
    "Following apps have been disabled: %s" : "Seuraavat sovellukset on poistettu käytöstä: %s",
    "Already up to date" : "Kaikki on jo ajan tasalla",
    "Very weak password" : "Erittäin heikko salasana",
    "Weak password" : "Heikko salasana",
    "So-so password" : "Kohtalainen salasana",
    "Good password" : "Hyvä salasana",
    "Strong password" : "Vahva salasana",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Palvelintasi ei ole määritetty oikein tiedostojen synkronointia varten, koska WebDAV-liitäntä vaikuttaa olevan rikki.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Palvelinta ei ole määritelty oikein tunnistamaan osoitetta \"{url}\". Katso lisätiedot <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ohjeista</a>.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Cron-työtä ei voitu suorittaa komentorivin kautta. Seuraavat tekniset virheet havaittiin:",
    "Check the background job settings" : "Tarkista taustatyön asetukset",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Välimuistia ei ole asennettu oikein. Suorituskykyä parantaaksesi, asenna memcache, jos käytettävissä. Katso lisätiedot <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ohjeista</a>.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Käytössä on PHP {version}. Suosittelemme päivittämään PHP:n hyötyäksesi <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">PHP Group:n suorituskyky- ja tietoturvapäivityksistä</a> niin pian kuin jakelusi sitä tukee.",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Käytössä on PHP 5.6. Nykyinen Nextcloudversio on viimeinen, mikä sitä tukee. Suositeltavaa on päivittää versioon 7.0+, jotta päivitys onnistuisi Nextcloud 14:än sen ilmestyessä.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached on määritelty hajautetuksi välimuistiksi, mutta väärä PHP-moduli \"memcache\" on asennettu. \\OC\\Memcache\\Memcached tukee vain modulia \"memcached\", mutta ei modulia \"memcache\". Katso <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wikiä molemmista moduleista</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Jotkin tiedostot eivät läpäisseet eheystarkistusta. Katso lisätietoa ongelman korjaamiseksi <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ohjeista</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Listaa virheelliset tiedostot…</a> / <a href=\"{rescanEndpoint}\">Skannaa uudelleen…</a>)",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP Opcache ei ole määritelty oikein. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Suosittelemme käyttämään paremman suorituskyvyn saavuttamiseksi ↗</a> seuraavia asetuksia <code>php.ini</code>-asetustiedostossa:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funktio \"set_time_limit\" ei ole käytettävissä. Tämä saattaa johtaa siihen, että skriptien suoritus päättyy ennenaikaisesti ja Nextcloud-asennus rikkoutuu. Funktion käyttäminen on erittäin suositeltavaa.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP-asennuksessasi ei ole FreeType-tukea, ja siitä aiheutuu profiilikuvien sekä asetuskäyttöliittymän rikkoutuminen.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Puuttuva indeksi \"{indexName}\" taulussa \"{tableName}\".",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite on parhaillaan käytössä tietokantaratkaisuna. Suuria asennuksia varten suosittelemme vaihtamaan toiseen tietokantaratkaisuun.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "Tee migraatio toiseen tietokantaan komentorivityökalulla: 'occ db:convert-type', tai lue <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaatio ↗</a>.",
    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Sisäänrakennetun php mailerin käyttö ei ole enää tuettua. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Päivitä sähköpostipalvelimesi asetukset ↗<a/>.",
    "The PHP memory limit is below the recommended value of 512MB." : "PHP:n muistiraja on asetettu alle suositellun 512 megatavun arvon.",
    "Error occurred while checking server setup" : "Virhe palvelimen määrityksiä tarkistaessa",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Data-hakemisto ja tiedostot ovat luultavasti käytettävissä suoraan Internetistä. .htaccess-tiedosto ei toimi oikein. Suosittelemme määrittämään HTTP-palvelimen asetukset siten, ettei data-hakemisto ole suoraan käytettävissä Internetistä tai siirtämään data-hakemiston HTTP-palvelimen juurihakemiston ulkopuolelle.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-header \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Kyseessä on mahdollinen tietoturvaan tai -suojaan liittyvä riski, joten on suositeltavaa muuttaa asetuksen arvoa.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP-header \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Jotkin toiminnot eivät vättämättä toimi oikein, joten on suositeltavaa muuttaa asetuksen arvoa.",
    "Shared" : "Jaettu",
    "Shared with" : "Jaettu",
    "Shared by" : "Jaettu",
    "Choose a password for the public link" : "Valitse salasana julkiselle linkille",
    "Choose a password for the public link or press the \"Enter\" key" : "Valitse salasana julkiselle linkille tai paina \"Enter\" näppäintä",
    "Copied!" : "Kopioitu!",
    "Copy link" : "Kopioi linkki",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "Copy" : "Kopioi",
    "Unable to create a link share" : "Linkkijaon tekeminen ei onnistunut",
    "Resharing is not allowed" : "Jakaminen uudelleen ei ole sallittu",
    "Link" : "Linkki",
    "Hide download" : "Piilota lataus",
    "Password protection enforced" : "Salasanasuojaus pakotettu",
    "Password protect" : "Suojaa salasanalla",
    "Password" : "Salasana",
    "Allow editing" : "Salli muokkaus",
    "Email link to person" : "Lähetä linkki sähköpostitse",
    "Send" : "Lähetä",
    "Allow upload and editing" : "Salli lähetys ja muokkaus",
    "Read only" : "Vain luku",
    "File drop (upload only)" : "Tiedostojen pudotus (Vain lähetys)",
    "Expiration date enforced" : "Vanhenemispäivä pakotettu",
    "Set expiration date" : "Aseta vanhenemispäivä",
    "Expiration" : "Vanheneminen",
    "Expiration date" : "Vanhenemispäivä",
    "Unshare" : "Lopeta jakaminen",
    "Delete share link" : "Poista jakolinkki",
    "Add another link" : "Lisää toinen linkki",
    "Password protection for links is mandatory" : "Linkkien salasanasuojaus on pakollista",
    "Share to {name}" : "Jaa henkilölle {name}",
    "Share link" : "Jaa linkki",
    "New share link" : "Uusi jakolinkki",
    "Created on {time}" : "Luotu {time}",
    "Could not unshare" : "Jakamisen lopettaminen epäonnistui",
    "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjältä {owner}",
    "Shared with you by {owner}" : "Jaettu kanssasi käyttäjältä {owner}",
    "Choose a password for the mail share" : "Valitse salasana sähköpostijaolle",
    "group" : "ryhmä",
    "remote" : "etä",
    "remote group" : "etäryhmä",
    "email" : "sähköposti",
    "conversation" : "keskustelu",
    "shared by {sharer}" : "jakanut {sharer}",
    "Can reshare" : "Voi uudelleenjakaa",
    "Can edit" : "Voi muokata",
    "Can create" : "Voi luoda",
    "Can change" : "Voi vaihtaa",
    "Can delete" : "Voi poistaa",
    "Access control" : "Pääsynhallinta",
    "Error while sharing" : "Virhe jaettaessa",
    "Share details could not be loaded for this item." : "Tämän kohteen jakamistietoja ei voitu ladata.",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Vähintään {count} kirjain vaaditaan automaattiseen täydentämiseen","Vähintään {count} kirjainta vaaditaan automaattiseen täydentämiseen"],
    "This list is maybe truncated - please refine your search term to see more results." : "Lista on ehkä vajaa - uudelleen määritä hakutermisi nähdäksesi lisää tuloksia.",
    "No users or groups found for {search}" : "Haulla {search} ei löytynyt käyttäjiä tai ryhmiä",
    "No users found for {search}" : "Haulla {search} ei löytynyt käyttäjiä",
    "An error occurred (\"{message}\"). Please try again" : "Tapahtui virhe (\"{message}\"). Yritä uudestaan",
    "An error occurred. Please try again" : "Tapahtui virhe, yritä uudelleen",
    "Home" : "Koti",
    "Work" : "Työ",
    "Other" : "Muu",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Jaa",
    "Name or email address..." : "Nimi tai sähköpostiosoite...",
    "Name or federated cloud ID..." : "Nimi tai federoidun pilven tunniste...",
    "Name, federated cloud ID or email address..." : "Nimi, federoidun pilven tunniste tai sähköpostiosoite...",
    "Name..." : "Nimi...",
    "Error" : "Virhe",
    "Error removing share" : "Virhe jakoa poistaessa",
    "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
    "restricted" : "rajoitettu",
    "invisible" : "näkymätön",
    "({scope})" : "({scope})",
    "Delete" : "Poista",
    "Rename" : "Nimeä uudelleen",
    "Collaborative tags" : "Yhteistyölliset tunnisteet",
    "No tags found" : "Tunnisteita ei löytynyt",
    "unknown text" : "tuntematon teksti",
    "Hello world!" : "Hei maailma!",
    "sunny" : "aurinkoinen",
    "Hello {name}, the weather is {weather}" : "Hei {name}, sää on {weather}",
    "Hello {name}" : "Hei {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Nämä ovat hakutulokset<script>alert(1)</script></strong>",
    "new" : "uusi",
    "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Päivitys on meneillään. Poistuminen tältä sivulta saattaa keskeyttää toimenpiteen joissain käyttöympäristöissä.",
    "Update to {version}" : "Päivitä versioon {version}",
    "An error occurred." : "Tapahtui virhe.",
    "Please reload the page." : "Päivitä sivu.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Päivitys epäonnistui. Katso lisätietoja tähän ongelmaan liittyen <a href=\"{url}\">keskustelupalstan viestistä</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Päivitys ei onnistunut. Raportoisitko tämän ongelman <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-yhteisölle</a>.",
    "Continue to Nextcloud" : "Jatka Nextcloudiin",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Päivitys onnistui. Siirryt Nextcloudiin %n sekunnin kuluttua.","Päivitys onnistui. Siirryt Nextcloudiin %n sekunnin kuluttua."],
    "Searching other places" : "Etsitään muista paikoista",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ei hakutuloksia muissa kansioissa haulla {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} hakutulos muussa kansiossa","{count} hakutulosta muissa kansioissa"],
    "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
    "Please contact your administrator." : "Ota yhteys ylläpitäjään.",
    "An internal error occurred." : "Tapahtui sisäinen virhe.",
    "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
    "Username or email" : "Käyttäjätunnus tai sähköpostiosoite",
    "Username or\temail" : "Käyttäjätunnus tai\tsähköposti",
    "Log in" : "Kirjaudu sisään",
    "Logging in …" : "Kirjaudutaan sisään...",
    "Wrong username or password." : "Väärä käyttäjätunnus tai salasana.",
    "User disabled" : "Käyttäjä poistettu käytöstä",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Useita virheellisiä kirjautumisyrityksiä havaittiin IP-osoitteestasi. Siksi seuraava yritys sallitaan vasta 30:n sekunnin päästä.",
    "Reset password" : "Palauta salasana",
    "Password can not be changed. Please contact your administrator." : "Salasanan vaihtaminen ei onnistunut. Ota yhteys ylläpitäjään.",
    "Back to login" : "Palaa kirjautumiseen",
    "Forgot password?" : "Unohditko salasanasi?",
    "Settings" : "Asetukset",
    "Could not load your contacts" : "Yhteystietojasi ei voitu ladata",
    "Search contacts …" : "Etsi yhteystietoja…",
    "No contacts found" : "Yhteystietoja ei löytynyt",
    "Show all contacts …" : "Näytä kaikki yhteystiedot…",
    "Loading your contacts …" : "Ladataan yhteystietojasi…",
    "Looking for {term} …" : "Etsii {term} …",
    "No" : "Ei",
    "Yes" : "Kyllä",
    "No files in here" : "Täällä ei ole tiedostoja",
    "New folder" : "Uusi kansio",
    "No more subfolders in here" : "Täällä ei ole enempää alikansioita",
    "Name" : "Nimi",
    "Size" : "Koko",
    "Modified" : "Muokattu",
    "{newName} already exists" : "{newName} on jo olemassa",
    "Choose" : "Valitse",
    "Move" : "Siirrä",
    "Error loading file picker template: {error}" : "Virhe ladatessa tiedostopohjia: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Virhe ladatessa viestipohjaa: {error}",
    "read-only" : "vain luku",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tiedoston ristiriita","{count} tiedoston ristiriita"],
    "One file conflict" : "Yhden tiedoston ristiriita",
    "New Files" : "Uudet tiedostot",
    "Already existing files" : "Jo olemassa olevat tiedostot",
    "Which files do you want to keep?" : "Mitkä tiedostot haluat säilyttää?",
    "If you select both versions, the copied file will have a number added to its name." : "Jos valitset kummatkin versiot, kopioidun tiedoston nimeen lisätään numero.",
    "Cancel" : "Peruuta",
    "Continue" : "Jatka",
    "(all selected)" : "(kaikki valittu)",
    "({count} selected)" : "({count} valittu)",
    "Error loading file exists template" : "Virhe ladatessa mallipohjaa",
    "Pending" : "Odottaa",
    "Copy to {folder}" : "Kopioi kansioon {folder}",
    "Move to {folder}" : "Siirrä kansioon {folder}",
    "Saving..." : "Tallennetaan...",
    "Authentication required" : "Tunnistautuminen vaaditaan",
    "This action requires you to confirm your password" : "Toiminto vaatii vahvistamista salasanallasi",
    "Confirm" : "Vahvista",
    "Failed to authenticate, try again" : "Varmennus epäonnistui, yritä uudelleen",
    "seconds ago" : "sekunteja sitten",
    "Connection to server lost" : "Yhteys palvelimelle katkesi",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua","Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua"],
    "Add to a project" : "Lisää projektiin",
    "Show details" : "Näytä tiedot",
    "Hide details" : "Piilota tiedot",
    "Rename project" : "Nimeä projekti uudelleen",
    "Failed to rename the project" : "Projektin nimeäminen uudelleen epäonnistui",
    "Failed to create a project" : "Projektin luominen epäonnistui",
    "Type to search for existing projects" : "Kirjoita etsiäksesi olemassa olevia projekteja",
    "New in" : "Uutta versiossa",
    "View changelog" : "Katso muutosloki",
    "No action available" : "Toimintoa ei saatavilla",
    "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
    "Personal" : "Henkilökohtainen",
    "Users" : "Käyttäjät",
    "Apps" : "Sovellukset",
    "Admin" : "Ylläpito",
    "Help" : "Ohje",
    "Access forbidden" : "Pääsy estetty",
    "File not found" : "Tiedostoa ei löytynyt",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Tätä asiakirjaa ei löytynyt palvelimelta. Kenties jako on poistettu tai se oli asetettu vanhenemaan.",
    "Internal Server Error" : "Sisäinen palvelinvirhe",
    "The server was unable to complete your request." : "Palvelin ei kyennyt käsittelemään pyyntöäsi.",
    "If this happens again, please send the technical details below to the server administrator." : "Jos tämä tapahtuu uudelleen, lähetä alla olevat tekniset tiedot palvelimen ylläpitäjälle.",
    "More details can be found in the server log." : "Lisätietoja on palvelimen lokitiedostossa.",
    "Technical details" : "Tekniset tiedot",
    "Remote Address: %s" : "Etäosoite: %s",
    "Request ID: %s" : "Pyynnön tunniste: %s",
    "Type: %s" : "Tyyppi: %s",
    "Code: %s" : "Koodi: %s",
    "Message: %s" : "Viesti: %s",
    "File: %s" : "Tiedosto: %s",
    "Line: %s" : "Rivi: %s",
    "Trace" : "Jälki",
    "Security warning" : "Turvallisuusvaroitus",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden nähtävissä Internetistä, koska .htaccess-tiedosto ei toimi.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Lisätietoja palvelimen kunnollisista asetuksista on <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ohjeissa</a>.",
    "Create an <strong>admin account</strong>" : "Luo <strong>ylläpitäjän tunnus</strong>",
    "Username" : "Käyttäjätunnus",
    "Storage & database" : "Tallennus ja tietokanta",
    "Data folder" : "Datakansio",
    "Configure the database" : "Määritä tietokanta",
    "Only %s is available." : "Vain %s on käytettävissä.",
    "Install and activate additional PHP modules to choose other database types." : "Asenna ja aktivoi erillisiä PHP-moduuleja valitaksesi muita tietokantatyyppejä.",
    "For more details check out the documentation." : "Lue lisätiedot ohjeista.",
    "Database user" : "Tietokannan käyttäjä",
    "Database password" : "Tietokannan salasana",
    "Database name" : "Tietokannan nimi",
    "Database tablespace" : "Tietokannan taulukkotila",
    "Database host" : "Tietokantapalvelin",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Määritä portin numero tietokantapalvelimen yhteydessä (esim. localhost:5432).",
    "Performance warning" : "Suorituskykyvaroitus",
    "You chose SQLite as database." : "Valitsit SQLiten tietokannaksi.",
    "Finish setup" : "Viimeistele asennus",
    "Finishing …" : "Viimeistellään…",
    "Need help?" : "Tarvitsetko apua?",
    "See the documentation" : "Tutustu ohjeisiin",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tämä sovellus vaatii toimiakseen JavaScript-tuen. {linkstart}Ota JavaScript käyttöön{linkend} ja päivitä sivu.",
    "Get your own free account" : "Hanki ilmainen tili itsellesi",
    "Skip to main content" : "Siirry pääsisältöön",
    "More apps" : "Lisää sovelluksia",
    "Search" : "Etsi",
    "Reset search" : "Tyhjennä haku",
    "Contacts" : "Yhteystiedot",
    "Contacts menu" : "Yhteystietovalikko",
    "Settings menu" : "Asetusvalikko",
    "Confirm your password" : "Vahvista salasanasi",
    "Connect to your account" : "Yhdistä tiliisi",
    "App token" : "Sovellusvaltuutus",
    "Grant access" : "Myönnä pääsy",
    "Account access" : "Tilin käyttö",
    "Account connected" : "Tili yhdistetty",
    "New password" : "Uusi salasana",
    "New Password" : "Uusi salasana",
    "This share is password-protected" : "Jako on salasanasuojattu",
    "The password is wrong. Try again." : "Salasana on väärin. Yritä uudelleen.",
    "Two-factor authentication" : "Kaksivaiheinen tunnistautuminen",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Tilisi tietoturvatasoa on korotettu. Käytä kaksivaiheista tunnistautumista:",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Kaksivaiheinen tunnistautuminen on pakotettu, mutta sitä ei ole määritelty tilillesi. Ole yhteydessä ylläpitoon saadaksesi apua.",
    "Set up two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
    "Use backup code" : "Käytä varakoodia",
    "Cancel log in" : "Peru kirjautuminen",
    "Setup two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
    "Error while validating your second factor" : "Tunnistuksen toisen vaiheen tarkistus epäonnistui",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Ota yhteys ylläpitoon, tai jos olet tämän palvelun ylläpitäjä, määritä \"trusted_domains\"-asetus config/config.php-tiedostossa. Esimerkkimääritys on tiedostossa config/config.sample.php.",
    "App update required" : "Sovelluksen päivittäminen vaaditaan",
    "%1$s will be updated to version %2$s" : "%1$s päivitetään versioon %2$s",
    "These apps will be updated:" : "Nämä sovellukset päivitetään:",
    "These incompatible apps will be disabled:" : "Nämä yhteensopimattomat sovellukset poistetaan käytöstä:",
    "The theme %s has been disabled." : "Teema %s on poistettu käytöstä.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Varmista ennen jatkamista, että tietokanta, asetuskansio ja datakansio on varmuuskopioitu.",
    "Start update" : "Käynnistä päivitys",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Välttääksesi aikakatkaisuja suurikokoisten asennusten kanssa, voit suorittaa vaihtoehtoisesti seuraavan komennon asennushakemistossa:",
    "Detailed logs" : "Yksityiskohtainen loki",
    "Update needed" : "Päivitys vaaditaan",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Käytä komentorivipäivitintä, koska käyttäjiä on yli 50.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Jos tarvitset apua, katso <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ohjeista</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tiedän että jos jatkan päivittämistä web-liittymän kautta, saatan menettää kaikki tiedostot, mikäli päivitys epäonnistuu. Onneksi olen tehnyt varmuuskopion ja osaan sen myös palauttaa tarvittaessa.",
    "Upgrade via web on my own risk" : "Internetin kautta päivittäminen omalla vastuulla",
    "Maintenance mode" : "Huoltotila",
    "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
    "This page will refresh itself when the instance is available again." : "Tämä sivu päivittyy itsestään, kun instanssi on jälleen käytettävissä.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
    "Updated \"%s\" to %s" : "Päivitetty \"%s\" versioon %s",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Eheystarkistus tuotti ongelmia. Lisätietoja…</a>",
    "Dismiss" : "Hylkää",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Linkki salasanan palauttamista varten on lähetetty sähköpostiisi. Jos et saa sähköpostiviestiä kohtuullisessa ajassa, tarkista roskapostikansiot.<br>Jos et saa sähköpostiviestiä, ota yhteys paikalliseen ylläpitäjään.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Tiedostosi ovat salattuja. Salasanan palauttamisen jälkeen niitä ei ole mahdollista palauttaa.<br />Jos et ole varma, mitä tehdä, ole yhteydessä ylläpitäjään ennen kuin jatkat.<br />Haluatko varmasti jatkaa?",
    "I know what I'm doing" : "Tiedän mitä teen",
    "Sending email …" : "Lähetetään sähköpostia ...",
    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} versiota {version} on asennettu. Vakauteen ja suorituskykyyn liittyvistä syistä suosittelemme, että {name} päivitetään uudempaan versioon.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom ei ole PHP:n luettavissa. Tämä ei ole suositeltavaa tietoturvasyistä. Lisätietoja <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ohjeissa</a>.",
    "Copy URL" : "Kopioi osoite",
    "Enable" : "Ota käyttöön",
    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} jakoi linkillä",
    "{sharee} (group)" : "{sharee} (ryhmä)",
    "{sharee} (remote)" : "{sharee} (etä)",
    "{sharee} (email)" : "{sharee} (sähköposti)",
    "The specified document has not been found on the server." : "Määritettyä asiakirjaa ei löytynyt palvelimelta.",
    "You can click here to return to %s." : "Napsauta tästä palataksesi %siin.",
    "SQLite will be used as database." : "SQLitea käytetään tietokantana.",
    "For larger installations we recommend to choose a different database backend." : "Suuria asennuksia varten suositellaan muun tietokannan käyttöä.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Varsinkin työpöytäsovelluksen tiedostosynkronointia käyttäessä SQLiten käyttö ei ole suositeltavaa.",
    "Wrong password." : "Väärä salasana.",
    "You are about to grant %s access to your %s account." : "Olet antamassa lupaa laitteelle %s päästä sinun %s tilille.",
    "Redirecting …" : "Ohjataan uudelleen…",
    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Tililläsi on käytössä parannettu tietoturva. Käytä tunnistuksen toista vaihetta.",
    "%s will be updated to version %s" : "%s päivitetään versioon %s",
    "This page will refresh itself when the %s instance is available again." : "Tämä sivu päivittää itsensä, kun %s on jälleen käytettävissä.",
    "Thank you for your patience." : "Kiitos kärsivällisyydestäsi."
},
"nplurals=2; plural=(n != 1);");
